==> aspose_barcode_cloud-0.23.6.tar.gz: lib/model/encode_barcode_type.dart <==
part of aspose_barcode_cloud.api;

class EncodeBarcodeType {
  EncodeBarcodeType._internal(this.value);

  EncodeBarcodeType.fromJson(dynamic data) {
    switch (data) {
      case "Codabar":
        value = data;
        break;
      case "Code11":
        value = data;
        break;
      case "Code39Standard":
        value = data;
        break;
      case "Code39Extended":
        value = data;
        break;
      case "Code93Standard":
        value = data;
        break;
      case "Code93Extended":
        value = data;
        break;
      case "Code128":
        value = data;
        break;
      case "GS1Code128":
        value = data;
        break;
      case "EAN8":
        value = data;
        break;
      case "EAN13":
        value = data;
        break;
      case "EAN14":
        value = data;
        break;
      case "SCC14":
        value = data;
        break;
      case "SSCC18":
        value = data;
        break;
      case "UPCA":
        value = data;
        break;
      case "UPCE":
        value = data;
        break;
      case "ISBN":
        value = data;
        break;
      case "ISSN":
        value = data;
        break;
      case "ISMN":
        value = data;
        break;
      case "Standard2of5":
        value = data;
        break;
      case "Interleaved2of5":
        value = data;
        break;
      case "Matrix2of5":
        value = data;
        break;
      case "ItalianPost25":
        value = data;
        break;
      case "IATA2of5":
        value = data;
        break;
      case "ITF14":
        value = data;
        break;
      case "ITF6":
        value = data;
        break;
      case "MSI":
        value = data;
        break;
      case "VIN":
        value = data;
        break;
      case "DeutschePostIdentcode":
        value = data;
        break;
      case "DeutschePostLeitcode":
        value = data;
        break;
      case "OPC":
        value = data;
        break;
      case "PZN":
        value = data;
        break;
      case "Code16K":
        value = data;
        break;
      case "Pharmacode":
        value = data;
        break;
      case "DataMatrix":
        value = data;
        break;
      case "QR":
        value = data;
        break;
      case "Aztec":
        value = data;
        break;
      case "Pdf417":
        value = data;
        break;
      case "MacroPdf417":
        value = data;
        break;
      case "AustraliaPost":
        value = data;
        break;
      case "Postnet":
        value = data;
        break;
      case "Planet":
        value = data;
        break;
      case "OneCode":
        value = data;
        break;
      case "RM4SCC":
        value = data;
        break;
      case "DatabarOmniDirectional":
        value = data;
        break;
      case "DatabarTruncated":
        value = data;
        break;
      case "DatabarLimited":
        value = data;
        break;
      case "DatabarExpanded":
        value = data;
        break;
      case "SingaporePost":
        value = data;
        break;
      case "GS1DataMatrix":
        value = data;
        break;
      case "AustralianPosteParcel":
        value = data;
        break;
      case "SwissPostParcel":
        value = data;
        break;
      case "PatchCode":
        value = data;
        break;
      case "DatabarExpandedStacked":
        value = data;
        break;
      case "DatabarStacked":
        value = data;
        break;
      case "DatabarStackedOmniDirectional":
        value = data;
        break;
      case "MicroPdf417":
        value = data;
        break;
      case "GS1QR":
        value = data;
        break;
      case "MaxiCode":
        value = data;
        break;
      case "Code32":
        value = data;
        break;
      case "DataLogic2of5":
        value = data;
        break;
      case "DotCode":
        value = data;
        break;
      case "DutchKIX":
        value = data;
        break;
      case "UpcaGs1Code128Coupon":
        value = data;
        break;
      case "UpcaGs1DatabarCoupon":
        value = data;
        break;
      case "CodablockF":
        value = data;
        break;
      case "GS1CodablockF":
        value = data;
        break;
      case "Mailmark":
        value = data;
        break;
      case "GS1DotCode":
        value = data;
        break;
      case "HanXin":
        value = data;
        break;
      case "GS1HanXin":
        value = data;
        break;
      default:
        throw Exception('Unknown enum value to decode: $data');
    }
  }

  /// The underlying value of this enum member.
  String? value;

  /// See EncodeTypes
  static EncodeBarcodeType codabar_ = EncodeBarcodeType._internal("Codabar");

  /// See EncodeTypes
  static EncodeBarcodeType code11_ = EncodeBarcodeType._internal("Code11");

  /// See EncodeTypes
  static EncodeBarcodeType code39Standard_ =
      EncodeBarcodeType._internal("Code39Standard");

  /// See EncodeTypes
  static EncodeBarcodeType code39Extended_ =
      EncodeBarcodeType._internal("Code39Extended");

  /// See EncodeTypes
  static EncodeBarcodeType code93Standard_ =
      EncodeBarcodeType._internal("Code93Standard");

  /// See EncodeTypes
  static EncodeBarcodeType code93Extended_ =
      EncodeBarcodeType._internal("Code93Extended");

  /// See EncodeTypes
  static EncodeBarcodeType code128_ = EncodeBarcodeType._internal("Code128");

  /// See EncodeTypes
  static EncodeBarcodeType gS1Code128_ =
      EncodeBarcodeType._internal("GS1Code128");

  /// See EncodeTypes
  static EncodeBarcodeType eAN8_ = EncodeBarcodeType._internal("EAN8");

  /// See EncodeTypes
  static EncodeBarcodeType eAN13_ = EncodeBarcodeType._internal("EAN13");

  /// See EncodeTypes
  static EncodeBarcodeType eAN14_ = EncodeBarcodeType._internal("EAN14");

  /// See EncodeTypes
  static EncodeBarcodeType sCC14_ = EncodeBarcodeType._internal("SCC14");

  /// See EncodeTypes
  static EncodeBarcodeType sSCC18_ = EncodeBarcodeType._internal("SSCC18");

  /// See EncodeTypes
  static EncodeBarcodeType uPCA_ = EncodeBarcodeType._internal("UPCA");

  /// See EncodeTypes
  static EncodeBarcodeType uPCE_ = EncodeBarcodeType._internal("UPCE");

  /// See EncodeTypes
  static EncodeBarcodeType iSBN_ = EncodeBarcodeType._internal("ISBN");

  /// See EncodeTypes
  static EncodeBarcodeType iSSN_ = EncodeBarcodeType._internal("ISSN");

  /// See EncodeTypes
  static EncodeBarcodeType iSMN_ = EncodeBarcodeType._internal("ISMN");

  /// See EncodeTypes
  static EncodeBarcodeType standard2of5_ =
      EncodeBarcodeType._internal("Standard2of5");

  /// See EncodeTypes
  static EncodeBarcodeType interleaved2of5_ =
      EncodeBarcodeType._internal("Interleaved2of5");

  /// See EncodeTypes
  static EncodeBarcodeType matrix2of5_ =
      EncodeBarcodeType._internal("Matrix2of5");

  /// See EncodeTypes
  static EncodeBarcodeType italianPost25_ =
      EncodeBarcodeType._internal("ItalianPost25");

  /// See EncodeTypes
  static EncodeBarcodeType iATA2of5_ = EncodeBarcodeType._internal("IATA2of5");

  /// See EncodeTypes
  static EncodeBarcodeType iTF14_ = EncodeBarcodeType._internal("ITF14");

  /// See EncodeTypes
  static EncodeBarcodeType iTF6_ = EncodeBarcodeType._internal("ITF6");

  /// See EncodeTypes
  static EncodeBarcodeType mSI_ = EncodeBarcodeType._internal("MSI");

  /// See EncodeTypes
  static EncodeBarcodeType vIN_ = EncodeBarcodeType._internal("VIN");

  /// See EncodeTypes
  static EncodeBarcodeType deutschePostIdentcode_ =
      EncodeBarcodeType._internal("DeutschePostIdentcode");

  /// See EncodeTypes
  static EncodeBarcodeType deutschePostLeitcode_ =
      EncodeBarcodeType._internal("DeutschePostLeitcode");

  /// See EncodeTypes
  static EncodeBarcodeType oPC_ = EncodeBarcodeType._internal("OPC");

  /// See EncodeTypes
  static EncodeBarcodeType pZN_ = EncodeBarcodeType._internal("PZN");

  /// See EncodeTypes
  static EncodeBarcodeType code16K_ = EncodeBarcodeType._internal("Code16K");

  /// See EncodeTypes
  static EncodeBarcodeType pharmacode_ =
      EncodeBarcodeType._internal("Pharmacode");

  /// See EncodeTypes
  static EncodeBarcodeType dataMatrix_ =
      EncodeBarcodeType._internal("DataMatrix");

  /// See EncodeTypes
  static EncodeBarcodeType qR_ = EncodeBarcodeType._internal("QR");

  /// See EncodeTypes
  static EncodeBarcodeType aztec_ = EncodeBarcodeType._internal("Aztec");

  /// See EncodeTypes
  static EncodeBarcodeType pdf417_ = EncodeBarcodeType._internal("Pdf417");

  /// See EncodeTypes
  static EncodeBarcodeType macroPdf417_ =
      EncodeBarcodeType._internal("MacroPdf417");

  /// See EncodeTypes
  static EncodeBarcodeType australiaPost_ =
      EncodeBarcodeType._internal("AustraliaPost");

  /// See EncodeTypes
  static EncodeBarcodeType postnet_ = EncodeBarcodeType._internal("Postnet");

  /// See EncodeTypes
  static EncodeBarcodeType planet_ = EncodeBarcodeType._internal("Planet");

  /// See EncodeTypes
  static EncodeBarcodeType oneCode_ = EncodeBarcodeType._internal("OneCode");

  /// See EncodeTypes
  static EncodeBarcodeType rM4SCC_ = EncodeBarcodeType._internal("RM4SCC");

  /// See EncodeTypes
  static EncodeBarcodeType databarOmniDirectional_ =
      EncodeBarcodeType._internal("DatabarOmniDirectional");

  /// See EncodeTypes
  static EncodeBarcodeType databarTruncated_ =
      EncodeBarcodeType._internal("DatabarTruncated");

  /// See EncodeTypes
  static EncodeBarcodeType databarLimited_ =
      EncodeBarcodeType._internal("DatabarLimited");

  /// See EncodeTypes
  static EncodeBarcodeType databarExpanded_ =
      EncodeBarcodeType._internal("DatabarExpanded");

  /// See EncodeTypes
  static EncodeBarcodeType singaporePost_ =
      EncodeBarcodeType._internal("SingaporePost");

  /// See EncodeTypes
  static EncodeBarcodeType gS1DataMatrix_ =
      EncodeBarcodeType._internal("GS1DataMatrix");

  /// See EncodeTypes
  static EncodeBarcodeType australianPosteParcel_ =
      EncodeBarcodeType._internal("AustralianPosteParcel");

  /// See EncodeTypes
  static EncodeBarcodeType swissPostParcel_ =
      EncodeBarcodeType._internal("SwissPostParcel");

  /// See EncodeTypes
  static EncodeBarcodeType patchCode_ =
      EncodeBarcodeType._internal("PatchCode");

  /// See EncodeTypes
  static EncodeBarcodeType databarExpandedStacked_ =
      EncodeBarcodeType._internal("DatabarExpandedStacked");

  /// See EncodeTypes
  static EncodeBarcodeType databarStacked_ =
      EncodeBarcodeType._internal("DatabarStacked");

  /// See EncodeTypes
  static EncodeBarcodeType databarStackedOmniDirectional_ =
      EncodeBarcodeType._internal("DatabarStackedOmniDirectional");

  /// See EncodeTypes
  static EncodeBarcodeType microPdf417_ =
      EncodeBarcodeType._internal("MicroPdf417");

  /// See EncodeTypes
  static EncodeBarcodeType gS1QR_ = EncodeBarcodeType._internal("GS1QR");

  /// See EncodeTypes
  static EncodeBarcodeType maxiCode_ = EncodeBarcodeType._internal("MaxiCode");

  /// See EncodeTypes
  static EncodeBarcodeType code32_ = EncodeBarcodeType._internal("Code32");

  /// See EncodeTypes
  static EncodeBarcodeType dataLogic2of5_ =
      EncodeBarcodeType._internal("DataLogic2of5");

  /// See EncodeTypes
  static EncodeBarcodeType dotCode_ = EncodeBarcodeType._internal("DotCode");

  /// See EncodeTypes
  static EncodeBarcodeType dutchKIX_ = EncodeBarcodeType._internal("DutchKIX");

  /// See EncodeTypes
  static EncodeBarcodeType upcaGs1Code128Coupon_ =
      EncodeBarcodeType._internal("UpcaGs1Code128Coupon");

  /// See EncodeTypes
  static EncodeBarcodeType upcaGs1DatabarCoupon_ =
      EncodeBarcodeType._internal("UpcaGs1DatabarCoupon");

  /// See EncodeTypes
  static EncodeBarcodeType codablockF_ =
      EncodeBarcodeType._internal("CodablockF");

  /// See EncodeTypes
  static EncodeBarcodeType gS1CodablockF_ =
      EncodeBarcodeType._internal("GS1CodablockF");

  /// See EncodeTypes
  static EncodeBarcodeType mailmark_ = EncodeBarcodeType._internal("Mailmark");

  /// See EncodeTypes
  static EncodeBarcodeType gS1DotCode_ =
      EncodeBarcodeType._internal("GS1DotCode");

  /// See EncodeTypes
  static EncodeBarcodeType hanXin_ = EncodeBarcodeType._internal("HanXin");

  /// See EncodeTypes
  static EncodeBarcodeType gS1HanXin_ =
      EncodeBarcodeType._internal("GS1HanXin");

  static dynamic encode(EncodeBarcodeType data) => data.value;

  String? toJson() => value;

  @override
  String toString() => value == null ? "null" : value.toString();
}

==> aspose_barcode_cloud-0.23.7.tar.gz: lib/model/encode_barcode_type.dart <==
part of aspose_barcode_cloud.api;

class EncodeBarcodeType {
  /// The underlying value of this enum member.
  String? value;

  EncodeBarcodeType._internal(this.value);

  /// See EncodeTypes
  static EncodeBarcodeType codabar_ = EncodeBarcodeType._internal("Codabar");

  /// See EncodeTypes
  static EncodeBarcodeType code11_ = EncodeBarcodeType._internal("Code11");

  /// See EncodeTypes
  static EncodeBarcodeType code39Standard_ =
      EncodeBarcodeType._internal("Code39Standard");

  /// See EncodeTypes
  static EncodeBarcodeType code39Extended_ =
      EncodeBarcodeType._internal("Code39Extended");

  /// See EncodeTypes
  static EncodeBarcodeType code93Standard_ =
      EncodeBarcodeType._internal("Code93Standard");

  /// See EncodeTypes
  static EncodeBarcodeType code93Extended_ =
      EncodeBarcodeType._internal("Code93Extended");

  /// See EncodeTypes
  static EncodeBarcodeType code128_ = EncodeBarcodeType._internal("Code128");

  /// See EncodeTypes
  static EncodeBarcodeType gS1Code128_ =
      EncodeBarcodeType._internal("GS1Code128");

  /// See EncodeTypes
  static EncodeBarcodeType eAN8_ = EncodeBarcodeType._internal("EAN8");

  /// See EncodeTypes
  static EncodeBarcodeType eAN13_ = EncodeBarcodeType._internal("EAN13");

  /// See EncodeTypes
  static EncodeBarcodeType eAN14_ = EncodeBarcodeType._internal("EAN14");

  /// See EncodeTypes
  static EncodeBarcodeType sCC14_ = EncodeBarcodeType._internal("SCC14");

  /// See EncodeTypes
  static EncodeBarcodeType sSCC18_ = EncodeBarcodeType._internal("SSCC18");

  /// See EncodeTypes
  static EncodeBarcodeType uPCA_ = EncodeBarcodeType._internal("UPCA");

  /// See EncodeTypes
  static EncodeBarcodeType uPCE_ = EncodeBarcodeType._internal("UPCE");

  /// See EncodeTypes
  static EncodeBarcodeType iSBN_ = EncodeBarcodeType._internal("ISBN");

  /// See EncodeTypes
  static EncodeBarcodeType iSSN_ = EncodeBarcodeType._internal("ISSN");

  /// See EncodeTypes
  static EncodeBarcodeType iSMN_ = EncodeBarcodeType._internal("ISMN");

  /// See EncodeTypes
  static EncodeBarcodeType standard2of5_ =
      EncodeBarcodeType._internal("Standard2of5");

  /// See EncodeTypes
  static EncodeBarcodeType interleaved2of5_ =
      EncodeBarcodeType._internal("Interleaved2of5");

  /// See EncodeTypes
  static EncodeBarcodeType matrix2of5_ =
      EncodeBarcodeType._internal("Matrix2of5");

  /// See EncodeTypes
  static EncodeBarcodeType italianPost25_ =
      EncodeBarcodeType._internal("ItalianPost25");

  /// See EncodeTypes
  static EncodeBarcodeType iATA2of5_ = EncodeBarcodeType._internal("IATA2of5");

  /// See EncodeTypes
  static EncodeBarcodeType iTF14_ = EncodeBarcodeType._internal("ITF14");

  /// See EncodeTypes
  static EncodeBarcodeType iTF6_ = EncodeBarcodeType._internal("ITF6");

  /// See EncodeTypes
  static EncodeBarcodeType mSI_ = EncodeBarcodeType._internal("MSI");

  /// See EncodeTypes
  static EncodeBarcodeType vIN_ = EncodeBarcodeType._internal("VIN");

  /// See EncodeTypes
  static EncodeBarcodeType deutschePostIdentcode_ =
      EncodeBarcodeType._internal("DeutschePostIdentcode");

  /// See EncodeTypes
  static EncodeBarcodeType deutschePostLeitcode_ =
      EncodeBarcodeType._internal("DeutschePostLeitcode");

  /// See EncodeTypes
  static EncodeBarcodeType oPC_ = EncodeBarcodeType._internal("OPC");

  /// See EncodeTypes
  static EncodeBarcodeType pZN_ = EncodeBarcodeType._internal("PZN");

  /// See EncodeTypes
  static EncodeBarcodeType code16K_ = EncodeBarcodeType._internal("Code16K");

  /// See EncodeTypes
  static EncodeBarcodeType pharmacode_ =
      EncodeBarcodeType._internal("Pharmacode");

  /// See EncodeTypes
  static EncodeBarcodeType dataMatrix_ =
      EncodeBarcodeType._internal("DataMatrix");

  /// See EncodeTypes
  static EncodeBarcodeType qR_ = EncodeBarcodeType._internal("QR");

  /// See EncodeTypes
  static EncodeBarcodeType aztec_ = EncodeBarcodeType._internal("Aztec");

  /// See EncodeTypes
  static EncodeBarcodeType pdf417_ = EncodeBarcodeType._internal("Pdf417");

  /// See EncodeTypes
  static EncodeBarcodeType macroPdf417_ =
      EncodeBarcodeType._internal("MacroPdf417");

  /// See EncodeTypes
  static EncodeBarcodeType australiaPost_ =
      EncodeBarcodeType._internal("AustraliaPost");

  /// See EncodeTypes
  static EncodeBarcodeType postnet_ = EncodeBarcodeType._internal("Postnet");

  /// See EncodeTypes
  static EncodeBarcodeType planet_ = EncodeBarcodeType._internal("Planet");

  /// See EncodeTypes
  static EncodeBarcodeType oneCode_ = EncodeBarcodeType._internal("OneCode");

  /// See EncodeTypes
  static EncodeBarcodeType rM4SCC_ = EncodeBarcodeType._internal("RM4SCC");

  /// See EncodeTypes
  static EncodeBarcodeType databarOmniDirectional_ =
      EncodeBarcodeType._internal("DatabarOmniDirectional");

  /// See EncodeTypes
  static EncodeBarcodeType databarTruncated_ =
      EncodeBarcodeType._internal("DatabarTruncated");

  /// See EncodeTypes
  static EncodeBarcodeType databarLimited_ =
      EncodeBarcodeType._internal("DatabarLimited");

  /// See EncodeTypes
  static EncodeBarcodeType databarExpanded_ =
      EncodeBarcodeType._internal("DatabarExpanded");

  /// See EncodeTypes
  static EncodeBarcodeType singaporePost_ =
      EncodeBarcodeType._internal("SingaporePost");

  /// See EncodeTypes
  static EncodeBarcodeType gS1DataMatrix_ =
      EncodeBarcodeType._internal("GS1DataMatrix");

  /// See EncodeTypes
  static EncodeBarcodeType australianPosteParcel_ =
      EncodeBarcodeType._internal("AustralianPosteParcel");

  /// See EncodeTypes
  static EncodeBarcodeType swissPostParcel_ =
      EncodeBarcodeType._internal("SwissPostParcel");

  /// See EncodeTypes
  static EncodeBarcodeType patchCode_ =
      EncodeBarcodeType._internal("PatchCode");

  /// See EncodeTypes
  static EncodeBarcodeType databarExpandedStacked_ =
      EncodeBarcodeType._internal("DatabarExpandedStacked");

  /// See EncodeTypes
  static EncodeBarcodeType databarStacked_ =
      EncodeBarcodeType._internal("DatabarStacked");

  /// See EncodeTypes
  static EncodeBarcodeType databarStackedOmniDirectional_ =
      EncodeBarcodeType._internal("DatabarStackedOmniDirectional");

  /// See EncodeTypes
  static EncodeBarcodeType microPdf417_ =
      EncodeBarcodeType._internal("MicroPdf417");

  /// See EncodeTypes
  static EncodeBarcodeType gS1QR_ = EncodeBarcodeType._internal("GS1QR");

  /// See EncodeTypes
  static EncodeBarcodeType maxiCode_ = EncodeBarcodeType._internal("MaxiCode");

  /// See EncodeTypes
  static EncodeBarcodeType code32_ = EncodeBarcodeType._internal("Code32");

  /// See EncodeTypes
  static EncodeBarcodeType dataLogic2of5_ =
      EncodeBarcodeType._internal("DataLogic2of5");

  /// See EncodeTypes
  static EncodeBarcodeType dotCode_ = EncodeBarcodeType._internal("DotCode");

  /// See EncodeTypes
  static EncodeBarcodeType dutchKIX_ = EncodeBarcodeType._internal("DutchKIX");

  /// See EncodeTypes
  static EncodeBarcodeType upcaGs1Code128Coupon_ =
      EncodeBarcodeType._internal("UpcaGs1Code128Coupon");

  /// See EncodeTypes
  static EncodeBarcodeType upcaGs1DatabarCoupon_ =
      EncodeBarcodeType._internal("UpcaGs1DatabarCoupon");

  /// See EncodeTypes
  static EncodeBarcodeType codablockF_ =
      EncodeBarcodeType._internal("CodablockF");

  /// See EncodeTypes
  static EncodeBarcodeType gS1CodablockF_ =
      EncodeBarcodeType._internal("GS1CodablockF");

  /// See EncodeTypes
  static EncodeBarcodeType mailmark_ = EncodeBarcodeType._internal("Mailmark");

  /// See EncodeTypes
  static EncodeBarcodeType gS1DotCode_ =
      EncodeBarcodeType._internal("GS1DotCode");

  /// See EncodeTypes
  static EncodeBarcodeType hanXin_ = EncodeBarcodeType._internal("HanXin");

  /// See EncodeTypes
  static EncodeBarcodeType gS1HanXin_ =
      EncodeBarcodeType._internal("GS1HanXin");

  EncodeBarcodeType.fromJson(dynamic data) {
    switch (data) {
      case "Codabar":
        value = data;
        break;
      case "Code11":
        value = data;
        break;
      case "Code39Standard":
        value = data;
        break;
      case "Code39Extended":
        value = data;
        break;
      case "Code93Standard":
        value = data;
        break;
      case "Code93Extended":
        value = data;
        break;
      case "Code128":
        value = data;
        break;
      case "GS1Code128":
        value = data;
        break;
      case "EAN8":
        value = data;
        break;
      case "EAN13":
        value = data;
        break;
      case "EAN14":
        value = data;
        break;
      case "SCC14":
        value = data;
        break;
      case "SSCC18":
        value = data;
        break;
      case "UPCA":
        value = data;
        break;
      case "UPCE":
        value = data;
        break;
      case "ISBN":
        value = data;
        break;
      case "ISSN":
        value = data;
        break;
      case "ISMN":
        value = data;
        break;
      case "Standard2of5":
        value = data;
        break;
      case "Interleaved2of5":
        value = data;
        break;
      case "Matrix2of5":
        value = data;
        break;
      case "ItalianPost25":
        value = data;
        break;
      case "IATA2of5":
        value = data;
        break;
      case "ITF14":
        value = data;
        break;
      case "ITF6":
        value = data;
        break;
      case "MSI":
        value = data;
        break;
      case "VIN":
        value = data;
        break;
      case "DeutschePostIdentcode":
        value = data;
        break;
      case "DeutschePostLeitcode":
        value = data;
        break;
      case "OPC":
        value = data;
        break;
      case "PZN":
        value = data;
        break;
      case "Code16K":
        value = data;
        break;
      case "Pharmacode":
        value = data;
        break;
      case "DataMatrix":
        value = data;
        break;
      case "QR":
        value = data;
        break;
      case "Aztec":
        value = data;
        break;
      case "Pdf417":
        value = data;
        break;
      case "MacroPdf417":
        value = data;
        break;
      case "AustraliaPost":
        value = data;
        break;
      case "Postnet":
        value = data;
        break;
      case "Planet":
        value = data;
        break;
      case "OneCode":
        value = data;
        break;
      case "RM4SCC":
        value = data;
        break;
      case "DatabarOmniDirectional":
        value = data;
        break;
      case "DatabarTruncated":
        value = data;
        break;
      case "DatabarLimited":
        value = data;
        break;
      case "DatabarExpanded":
        value = data;
        break;
      case "SingaporePost":
        value = data;
        break;
      case "GS1DataMatrix":
        value = data;
        break;
      case "AustralianPosteParcel":
        value = data;
        break;
      case "SwissPostParcel":
        value = data;
        break;
      case "PatchCode":
        value = data;
        break;
      case "DatabarExpandedStacked":
        value = data;
        break;
      case "DatabarStacked":
        value = data;
        break;
      case "DatabarStackedOmniDirectional":
        value = data;
        break;
      case "MicroPdf417":
        value = data;
        break;
      case "GS1QR":
        value = data;
        break;
      case "MaxiCode":
        value = data;
        break;
      case "Code32":
        value = data;
        break;
      case "DataLogic2of5":
        value = data;
        break;
      case "DotCode":
        value = data;
        break;
      case "DutchKIX":
        value = data;
        break;
      case "UpcaGs1Code128Coupon":
        value = data;
        break;
      case "UpcaGs1DatabarCoupon":
        value = data;
        break;
      case "CodablockF":
        value = data;
        break;
      case "GS1CodablockF":
        value = data;
        break;
      case "Mailmark":
        value = data;
        break;
      case "GS1DotCode":
        value = data;
        break;
      case "HanXin":
        value = data;
        break;
      case "GS1HanXin":
        value = data;
        break;
      default:
        throw Exception('Unknown enum value to decode: $data');
    }
  }

  static dynamic encode(EncodeBarcodeType data) {
    return data.value;
  }

  String? toJson() {
    return value;
  }

  String toString() {
    return value == null ? "null" : value.toString();
  }
}
